@@ -22,10 +22,11 @@ class CausalLMModelForOnnxGeneration(PreTrainedModel):
         self.session = onnxruntime.InferenceSession(onnx_model_path, sess_options)
 
     @classmethod
-    def from_pretrained(cls, model_name_path: str):
-        transformers_onnx_pipeline(model_name_path)
+    def from_pretrained(cls, model_name_path: str, threads=0):
         onnx_path = os.path.join(model_name_path, "onnx/model-quantized.onnx")
-        return cls(onnx_path, model_path=model_name_path)
+        if not os.path.exists(onnx_path):
+            transformers_onnx_pipeline(model_name_path)
+        return cls(onnx_path, model_path=model_name_path, threads=threads)
 
     def forward(
         self,
@@ -44,13 +45,12 @@ class CausalLMModelForOnnxGeneration(PreTrainedModel):
         output_hidden_states: Optional[bool] = None,
         return_dict: Optional[bool] = None,
     ):
-
         if past_key_values is None:
             past_key_values_array = np.zeros(
                 [
                     self.config.n_layer,
                     2,
-                    1,
+                    input_ids.shape[0],
                     self.config.n_head,
                     0,
                     int(self.config.n_embd / self.config.n_head),
@@ -62,7 +62,7 @@ class CausalLMModelForOnnxGeneration(PreTrainedModel):
             )
         if attention_mask is None:
             attention_mask = np.array(
-                [[1] * int(past_key_values_array.shape[-2] + input_ids.shape[1])]
+                [[1] * int(past_key_values_array.shape[-2] + input_ids.shape[1])]*input_ids.shape[0]
             )
         else:
             attention_mask = attention_mask.cpu().numpy()
@@ -84,3 +84,44 @@ class CausalLMModelForOnnxGeneration(PreTrainedModel):
             attentions=None,
             cross_attentions=None,
         )
+
+    @staticmethod
+    def _reorder_cache(past: Tuple[Tuple[torch.Tensor]], beam_idx: torch.Tensor) -> Tuple[Tuple[torch.Tensor]]:
+        """
+        This function is used to re-order the `past_key_values` cache if [`~PreTrainedModel.beam_search`] or
+        [`~PreTrainedModel.beam_sample`] is called. This is required to match `past_key_values` with the correct
+        beam_idx at every generation step.
+        """
+        return tuple(
+            tuple(past_state.index_select(0, beam_idx.to(past_state.device)) for past_state in layer_past)
+            for layer_past in past
+        )
+
+    def prepare_inputs_for_generation(self, input_ids, past=None, **kwargs):
+        token_type_ids = kwargs.get("token_type_ids", None)
+        # only last token for inputs_ids if past is defined in kwargs
+        if past:
+            input_ids = input_ids[:, -1].unsqueeze(-1)
+            if token_type_ids is not None:
+                token_type_ids = token_type_ids[:, -1].unsqueeze(-1)
+
+        attention_mask = kwargs.get("attention_mask", None)
+        position_ids = kwargs.get("position_ids", None)
+
+        if attention_mask is not None and position_ids is None:
+            # create position_ids on the fly for batch generation
+            position_ids = attention_mask.long().cumsum(-1) - 1
+            position_ids.masked_fill_(attention_mask == 0, 1)
+            if past:
+                position_ids = position_ids[:, -1].unsqueeze(-1)
+        else:
+            position_ids = None
+
+        return {
+            "input_ids": input_ids,
+            "past_key_values": past,
+            "use_cache": kwargs.get("use_cache"),
+            "position_ids": position_ids,
+            "attention_mask": attention_mask,
+            "token_type_ids": token_type_ids,
+        }
